Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(180)

Unified Diff: Source/WebKit/chromium/src/WorkerFileSystemCallbacksBridge.h

Issue 17648006: Rename WorkerContext to WorkerGlobalScope (Closed) Base URL: svn://svn.chromium.org/blink/trunk
Patch Set: Rebase on master Created 7 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: Source/WebKit/chromium/src/WorkerFileSystemCallbacksBridge.h
diff --git a/Source/WebKit/chromium/src/WorkerFileSystemCallbacksBridge.h b/Source/WebKit/chromium/src/WorkerFileSystemCallbacksBridge.h
index 077c2081d8fe5ca59239c441d39582185db43f6b..0cb216b128e4e5360e367aeb8e919fb6f7c9154d 100644
--- a/Source/WebKit/chromium/src/WorkerFileSystemCallbacksBridge.h
+++ b/Source/WebKit/chromium/src/WorkerFileSystemCallbacksBridge.h
@@ -77,9 +77,9 @@ public:
void stop();
- static PassRefPtr<WorkerFileSystemCallbacksBridge> create(WebCore::WorkerLoaderProxy* workerLoaderProxy, WebCore::ScriptExecutionContext* workerContext, WebFileSystemCallbacksImpl* callbacks)
+ static PassRefPtr<WorkerFileSystemCallbacksBridge> create(WebCore::WorkerLoaderProxy* workerLoaderProxy, WebCore::ScriptExecutionContext* workerGlobalScope, WebFileSystemCallbacksImpl* callbacks)
{
- return adoptRef(new WorkerFileSystemCallbacksBridge(workerLoaderProxy, workerContext, callbacks));
+ return adoptRef(new WorkerFileSystemCallbacksBridge(workerLoaderProxy, workerGlobalScope, callbacks));
}
// Methods that create an instance and post an initial request task to the main thread. They must be called on the worker thread.
@@ -142,10 +142,10 @@ private:
Mutex m_loaderProxyMutex;
WebCore::WorkerLoaderProxy* m_workerLoaderProxy;
- WebCore::ScriptExecutionContext* m_workerContext;
+ WebCore::ScriptExecutionContext* m_workerGlobalScope;
- // Must be deleted on the WorkerContext thread.
- WorkerFileSystemContextObserver* m_workerContextObserver;
+ // Must be deleted on the WorkerGlobalScope thread.
+ WorkerFileSystemContextObserver* m_workerGlobalScopeObserver;
// This is self-destructed and must be fired on the worker thread.
WebFileSystemCallbacksImpl* m_callbacksOnWorkerThread;

Powered by Google App Engine
This is Rietveld 408576698